@@ -6,7 +6,7 @@
 # Change 1..1 below to 1..last_test_to_print .
 # (It may become useful if the test is moved to ./t subdirectory.)
 
-BEGIN { $| = 1; print "1..5\n"; }
+BEGIN { $| = 1; print "1..6\n"; }
 END {print "not ok 1\n" unless $loaded;}
 use Parse::FixedLength;
 $loaded = 1;
@@ -46,3 +46,8 @@ if ($href->{address} eq '1122 Main St.') {
 } else {
     print "not ok 5\n";
 }
+if ($parser->length == 40) {
+    print "ok 6\n";
+} else {
+    print "not ok 6\n";
+}
